@@ -4,33 +4,7 @@ import platform
 
 
 def load_library(libname, loader_path):
-    """
-    It is possible to load a library using
-    >>> lib = ctypes.cdll[<full_path_name>] # doctest: +SKIP
-
-    But there are cross-platform considerations, such as library file extensions,
-    plus the fact Windows will just load the first library it finds with that name.
-    NumPy supplies the load_library function as a convenience.
-
-    Parameters
-    ----------
-    libname : str
-        Name of the library, which can have 'lib' as a prefix,
-        but without an extension.
-    loader_path : str
-        Where the library can be found.
-
-    Returns
-    -------
-    ctypes.cdll[libpath] : library object
-        A ctypes library object
-
-    Raises
-    ------
-    OSError
-        If there is no library with the expected extension, or the
-        library is defective and cannot be loaded.
-    """
+    
     if ctypes.__version__ < '1.0.1':
         import warnings
         warnings.warn("All features of ctypes interface may not work "
@@ -71,11 +45,15 @@ def load_library(libname, loader_path):
     
 
 
-dll_name = 'libkdv.dll'
+dll_names = ['libkdv.dll','libkdv_mac.dll','libkdv_mac_M1.dll','libkdv_win64.dll']
 
-library_path = os.path.abspath(os.path.join(os.path.dirname(__file__), dll_name))
-
-rapid_kdv_C_library = load_library('rapid_kdv',library_path)
+for dll_name in dll_names:
+    try:
+        library_path = os.path.abspath(os.path.join(os.path.dirname(__file__), dll_name))
+        rapid_kdv_C_library = load_library(dll_name,library_path)
+        break
+    except:
+        pass
 rapid_kdv = rapid_kdv_C_library.kdv
 rapid_kdv.argtypes = (ctypes.c_int,ctypes.POINTER(ctypes.c_char_p))
 rapid_kdv.restype = ctypes.c_char_p
